# 0.3.1 (2021-04-06)

Switched from Travis CI to Github Actions. Otherwise, nothing changed.

# 0.3.0 (2020-07-03)

### Features

- Get podcast by iTunes ID.
- Default search country is US.

# 0.2.0 (2020-07-01)

### Features

- Filter by country and return episode count

# 0.1.0 (2020-05-13)

### Features

-   Search iTunes
